---
name: Feature request
about: Suggest an idea for this project
title: ""
labels: "💡 Enhancement"
assignees: ""
---

## Problem description

<!-- Is your feature request related to a problem? Please provide a clear and
concise description of what the problem is. [Example: "I'm always frustrated
when ..." -->

## Proposed solution

<!-- Describe the solution you'd want to happen. -->

<!-- Are there alternatives you have considered? -->

<!-- Additional context: -->
<!-- Add any other context or screenshots about the feature -->
